// vi: tabstop=4 shiftwidth=4 noexpandtab
/*
Gwenview - A simple image viewer for TDE
Copyright 2005 Aurelien Gateau

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

*/
#ifndef THUMBNAILDETAILSDIALOG_H
#define THUMBNAILDETAILSDIALOG_H   

// KDE
#include <kdialogbase.h>

namespace Gwenview {

class FileThumbnailView;

class ThumbnailDetailsDialog : public KDialogBase {
Q_OBJECT
  
public:
	ThumbnailDetailsDialog(FileThumbnailView* view);
	~ThumbnailDetailsDialog();

private slots:
	void applyChanges();

private:
	struct Private;
	Private* d;
};

} // namespace

#endif /* THUMBNAILDETAILSDIALOG_H */
